@@ -480,11 +480,47 @@ inspection_arguments = [1, 0, 1.2, 'abc', '1', '0', '1.2', '1/2', {1, 2, 3}, {'a
                         "(iter(b'2'))", "(iter(b'a'))", '(iter(bytearray(1)))']
 
 
-def diff(arg1, arg2, p=0):
-    returned_dict = {f'{arg1} - {arg2}': set(dir(arg1)) - set(dir(arg2)),
-                     f'{arg2} - {arg1}': set(dir(arg2)) - set(dir(arg1)),
-                     f'{arg2} ^ {arg1}': set(dir(arg2)) ^ set(dir(arg1))}
-    if p == 1:
+def diff2(arg1, arg2, show_graph=0, p=0):
+    dir_arg1 = set(dir(arg1))
+    dir_arg2 = set(dir(arg2))
+    returned_dict = {f'{arg1} - {arg2}': dir_arg1 - dir_arg2,
+                     f'{arg2} - {arg1}': dir_arg2 - dir_arg1,
+                     f'{arg1} & {arg2}': dir_arg1 & dir_arg2}
+
+    if show_graph:
+        import upsetplot
+        graph_dict = {f'{arg1}': dir_arg1,
+                      f'{arg2}': dir_arg2}
+
+        upset_data_sub = upsetplot.from_contents({k: v for k, v in graph_dict.items()})
+        upsetplot.plot(upset_data_sub, show_counts=True)
+
+    if p:
+        from pprint import pprint
+        pprint(returned_dict, compact=True, width=120)
+    else:
+        return returned_dict
+
+
+def diff3(arg1, arg2, arg3, show_graph=0, p=0):
+    returned_dict = {f'{arg1} - {arg2} - {arg3}': set(dir(arg1)) - set(dir(arg2)) - set(dir(arg3)),
+                     f'{arg2} - {arg1} - {arg3}': set(dir(arg2)) - set(dir(arg1)) - set(dir(arg3)),
+                     f'{arg3} - {arg1} - {arg2}': set(dir(arg3)) - set(dir(arg1)) - set(dir(arg2)),
+                     f'{arg1} & {arg2} - {arg3}': set(dir(arg1)) & set(dir(arg2)) - set(dir(arg3)),
+                     f'{arg2} & {arg3} - {arg1}': set(dir(arg2)) & set(dir(arg3)) - set(dir(arg1)),
+                     f'{arg1} & {arg3} - {arg2}': set(dir(arg1)) & set(dir(arg3)) - set(dir(arg2)),
+                     f'{arg1} & {arg2} & {arg3}': set(dir(arg1)) & set(dir(arg2)) & set(dir(arg3))}
+
+    if show_graph:
+        import upsetplot
+        graph_dict = {f'{arg1}': set(dir(arg1)),
+                      f'{arg2}': set(dir(arg2)),
+                      f'{arg3}': set(dir(arg3))}
+
+        upset_data_sub = upsetplot.from_contents({k: v for k, v in graph_dict.items()})
+        upsetplot.plot(upset_data_sub, show_counts=True)
+
+    if p:
         from pprint import pprint
         pprint(returned_dict, compact=True, width=120)
     else:
